summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/godpassive.h
diff options
context:
space:
mode:
authorelliptic <hyperelliptical@gmail.com>2011-06-23 23:51:25 -0400
committerelliptic <hyperelliptical@gmail.com>2011-06-24 01:01:27 -0400
commit0cc5d388db877b2ae3d83c91d620d95b170adfde (patch)
treebe9bfa4be414eaf576f48ce7427e7f3bdd7facc3 /crawl-ref/source/godpassive.h
parent5b1bdd34d6a733f8a5f9302349861148742cd676 (diff)
downloadcrawl-ref-0cc5d388db877b2ae3d83c91d620d95b170adfde.tar.gz
crawl-ref-0cc5d388db877b2ae3d83c91d620d95b170adfde.zip
Make ponderous items have a larger effect on characters with limited armour slots.
Previously each ponderous item increased the movement delay of the player by 2; now the movement delay is increased by (# of ponderous items worn * 10)/(# of available non-shield armour slots). The purpose of this is to make Cheibriados a reasonable god choice for all races; previously he was biased against some races for no apparent reason. Now all races (except felids) can obtain the maximum stat boost of +15 from Chei. To smooth things out a bit for slot-limited races, the stat boost progression was changed from quadratic to linear; this means that humans now have stat boosts of +3/6/9/12/15 depending on piety and ponderousness, whereas ogres have stat boosts of +4/9/15 (with intermediate values possible if piety is insufficiently high). Thus this is also a general buff to Chei at lower levels of piety/ponderousness. Octopodes aren't special-cased for this at the moment, so wearing a ponderous hat brings them all the way to movement delay 20... but they still need high piety for the maximum stat boost. This isn't really ideal, but it does mean that Chei is an option for octopodes... if they have a hat.
Diffstat (limited to 'crawl-ref/source/godpassive.h')
-rw-r--r--crawl-ref/source/godpassive.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/godpassive.h b/crawl-ref/source/godpassive.h
index 1e94259ebc..87fc13f6d1 100644
--- a/crawl-ref/source/godpassive.h
+++ b/crawl-ref/source/godpassive.h
@@ -21,7 +21,8 @@ enum che_boost_type
enum che_change_type
{
CB_PIETY, // Change in piety_rank.
- CB_PONDEROUS, // Change in number of worn ponderous items.
+ CB_PONDEROUSNESS, // Change in ponderousness.
+ CB_PONDEROUS_COUNT, // Change in number of worn ponderous items.
};
enum jiyva_slurp_results